Documentation
¶
Overview ¶
Copyright (C) 2026 l3montree GmbH
This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type StringSlice ¶
type StringSlice []string
StringSlice is a string slice that can be stored as JSONB in PostgreSQL. This allows for easy querying of array elements using PostgreSQL's JSONB operators.
func (*StringSlice) Scan ¶
func (s *StringSlice) Scan(value any) error
Scan unmarshals JSON from the database into the slice.
func (StringSlice) String ¶
func (s StringSlice) String() string
String returns the slice as a string representation for hashing purposes.